EXEC [dbo].[__AddStoredProcInfo]
    /* StoredProc_Name         */ 'ClusterNodes_CreateOrUpdate',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Creates or updates a node in the cluster.'
GO

IF OBJECT_ID('[ClusterNodes_CreateOrUpdate]') IS NOT NULL
	DROP PROCEDURE [ClusterNodes_CreateOrUpdate]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [ClusterNodes_CreateOrUpdate]
(
	@Server_Name NVARCHAR(64),
	@NodeType_Code CHAR(1),

	@Node_Configuration XML
)
AS
BEGIN
SET NOCOUNT ON

BEGIN TRY

	BEGIN TRANSACTION

	DECLARE @Now DATETIME
	SET @Now = GETUTCDATE()

	UPDATE [ClusterNodes] WITH (UPDLOCK, SERIALIZABLE) 
	   SET [LastUpdated_Date] = @Now,
		   [Node_Configuration] = @Node_Configuration
	 WHERE [Server_Name] = @Server_Name 
	   AND [NodeType_Code] = @NodeType_Code

	IF @@ROWCOUNT = 0 BEGIN

		INSERT INTO [ClusterNodes] ([Server_Name], [NodeType_Code], [LastUpdated_Date], [Node_Configuration], [Primary_Indicator])
		VALUES (@Server_Name, @NodeType_Code, @Now, @Node_Configuration, 'N')

	END

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH


END
GO

GRANT EXECUTE ON [ClusterNodes_CreateOrUpdate] TO [ProGetUser_Role]
GO
