EXEC [__AddStoredProcInfo]
    /* StoredProc_Name         */ 'RpmPackages_SetRepositoryData',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Sets repository information about an RPM feed.'
GO

IF OBJECT_ID('[RpmPackages_SetRepositoryData]') IS NOT NULL DROP PROCEDURE [RpmPackages_SetRepositoryData]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [RpmPackages_SetRepositoryData]
(
	@Feed_Id INT,
	@DataType_Name VARCHAR(20),
	@SHA256_Bytes BINARY(32),
	@Open_SHA256_Bytes BINARY(32),
	@Data_Size BIGINT,
	@Open_Data_Size BIGINT
)
AS
BEGIN

SET NOCOUNT ON

	IF EXISTS(SELECT * FROM [RpmRepositoryData] WHERE [Feed_Id] = @Feed_Id AND [DataType_Name] = @DataType_Name)

		UPDATE [RpmRepositoryData]
		   SET [SHA256_Bytes] = @SHA256_Bytes,
		       [Open_SHA256_Bytes] = @Open_SHA256_Bytes,
			   [Data_Size] = @Data_Size,
			   [Open_Data_Size] = @Open_Data_Size,
			   [Generated_Date] = GETUTCDATE(),
			   [Revision_Number] = [Revision_Number] + 1,
			   [DirtySince_Date] = NULL
		 WHERE [Feed_Id] = @Feed_Id
		   AND [DataType_Name] = @DataType_Name

	ELSE

		INSERT INTO [RpmRepositoryData]
		(
			[Feed_Id],
			[DataType_Name],
			[SHA256_Bytes],
			[Open_SHA256_Bytes],
			[Data_Size],
			[Open_Data_Size],
			[Generated_Date],
			[Revision_Number]
		)
		VALUES
		(
			@Feed_Id,
			@DataType_Name,
			@SHA256_Bytes,
			@Open_SHA256_Bytes,
			@Data_Size,
			@Open_Data_Size,
			GETUTCDATE(),
			1
		)

END
GO

GRANT EXECUTE ON [RpmPackages_SetRepositoryData] TO [ProGetUser_Role]
GO